A burndown object, i.e. one inheriting from
burndown-class.
col
list of colours for items, starting with the first key in the
file (which will be at the bottom of the chart). If not specified, the
hcl scheme will be used, to generate colours that are
distinct, that show up reasonably well on a monitor.
draw.plan
boolean, set to TRUE to draw the plan, as a
descending line with a horizontal intercept.
draw.regression
boolean, set to TRUE to draw a regression line
of actual overall progress.
draw.lastupdate
boolean, set to TRUE to draw the last update
(which otherwise requires a sharp eye).
t.stop
a POSIX time, the maximum time for graph (defaults to deadline
if not given).
y.name
character string, for labelling the vertical axis.